<?php

//Timeline Post Type and custom taxonomy for categories
add_action('init', 'register_timeline_post_type');
function register_timeline_post_type() {

	register_post_type(
		'timeline',
		array(
			'labels' => array(
				'name' => __('Timeline','wedding')
			),
			'public' => false,
			'has_archive' => false,
			'show_ui' => true,
			'show_in_menu' => true,
			'rewrite' => false,
			'supports' => array('title', 'editor', 'thumbnail','post-formats','custom-fields'),
			'menu_icon' => get_template_directory_uri() . '/includes/static/images/timeline_marker.png'
		)
	);
	
	register_taxonomy('timeline-category', 'timeline', array(
		'hierarchical' => true,
		'show_admin_column' => true,
	));
	
}
//Timeline Post Type and custom taxonomy for categories

//Menu current class if its single timeline page
function timeline_change_page_menu_classes($menu){
	global $post;
	if (get_post_type($post) == 'timeline')
	{
		$timeline_parent = '';
		
		$timeline_parent = get_pages(array(
			'meta_key' => '_wp_page_template',
			'meta_value' => 'page-templates/timeline.php',
			'hierarchical' => 0
		));
		
		$timeline_parent = $timeline_parent[0]->ID;
		global $wpdb;
		$timeline_parent = $wpdb->get_var( 'SELECT post_id FROM '.$wpdb->postmeta.' WHERE meta_key="_menu_item_object_id" AND meta_value="'.$timeline_parent.'"' );
		$menu = str_replace( 'current_page_parent', '', $menu );
		$menu = str_replace( 'menu-item-'.$timeline_parent.'" class="', 'menu-item-'.$timeline_parent.'" class="current_page_parent ', $menu );
	}
	return $menu;
}
add_filter( 'wp_nav_menu', 'timeline_change_page_menu_classes', 0 );
//Menu current class if its single timeline page

//Get timeline homepage link
function get_timeline_homepage() {
	$pages = get_pages(array(
		'meta_key' => '_wp_page_template',
		'meta_value' => 'page-templates/timeline.php'
	));

	$link = get_permalink($pages[0]->ID);	

	return $link;
}
//Get timeline homepage link

//Timeline Post Format Additional Options
add_action('admin_init', 'register_timeline_post_format_additionals');
function register_timeline_post_format_additionals() {

	if (version_compare(get_bloginfo('version'),"3.6",">=")) {
		add_filter( 'hidden_meta_boxes', 'custom_hidden_meta_boxes_timeline' );
		function custom_hidden_meta_boxes_timeline( $hidden ) {
		    $hidden[] = 'post_format_additionals_old';
		    return $hidden;
		}
		$post_format_metabox_id = 'post_format_additionals_old';
	} else {
		$post_format_metabox_id = 'post_format_additionals';
	}

	add_meta_box($post_format_metabox_id, __('Post Format Additional Options','wedding'), 'post_format_additionals_callback', 'timeline', 'side', 'low');

}
//Timeline Post Format Additional Options

//Timeline category selector for timeline template
add_action('admin_init', 'register_timeline_category_field');
add_action('save_post', 'save_timeline_category_meta',10,2);

function register_timeline_category_field() {
	add_meta_box('timeline_category_meta', __('Timeline Options','wedding'), 'timeline_category_meta_callback', 'page', 'side', 'low');
}

function timeline_category_meta_callback() {
	global $post;
	$custom = get_post_custom($post->ID);

	$old_value = '';
	if (isset($custom['timeline_category'][0])) $old_value = $custom['timeline_category'][0];
	$timeline_order = 'ASC';
	if (isset($custom['timeline_order'][0])) $timeline_order = $custom['timeline_order'][0];
	$timeline_date = 'Y';
	if (isset($custom['timeline_date'][0])) $timeline_date = $custom['timeline_date'][0];
	$timeline_date_item = 'F jS';
	if (isset($custom['timeline_date_item'][0])) $timeline_date_item = $custom['timeline_date_item'][0];
	
	wp_nonce_field( basename( __FILE__ ), 'timeline_category_nonce' );
	
	?>
	<p><strong><?php _e('Show posts from the following category','wedding') ?>:</strong></p>
	<p>
		<?php wp_dropdown_categories(array(
			'show_option_all' => __('From all','wedding'),
			'taxonomy' => 'timeline-category',
			'name' => 'timeline_category',
			'selected' => $old_value
		)); ?>
	</p>
	<p><strong><?php _e('Timeline Order','wedding'); ?></strong></p>
	<p>
		<select class="select" name="timeline_order">
			<option value="ASC"<?php if($timeline_order == 'ASC'):?> selected="selected"<?php endif; ?>><?php _e('Ascending','wedding'); ?></option>
			<option value="DESC"<?php if($timeline_order == 'DESC'):?> selected="selected"<?php endif; ?>><?php _e('Descending','wedding'); ?></option>
		</select>
	</p>
	<p>
		<strong><?php _e('Grouping Date Format','wedding'); ?></strong>
		<input type="text" value="<?php echo $timeline_date; ?>" name="timeline_date" /><br/>
		<small class="howto"><?php _e('Date Format on the timeline. Default value is Y, which groups the timeline posts by year. You can find all of the available date codes <a href="http://codex.wordpress.org/Formatting_Date_and_Time">here</a>. For example, if you want to group your timeline items in months, use F','wedding'); ?></small><br/>
	</p>
	<p>
		<strong><?php _e('Item Date Format','wedding'); ?></strong>
		<input type="text" value="<?php echo $timeline_date_item; ?>" name="timeline_date_item" /><br/>
		<small class="howto"><?php _e('Date Format for the timeline items, same options as above.','wedding'); ?></small><br/>
	</p>
	<?php
}

function save_timeline_category_meta($post_id, $post) {
	global $post;

	if ( !isset( $_POST['timeline_category_nonce'] ) || !wp_verify_nonce( $_POST['timeline_category_nonce'], basename( __FILE__ ) ) )
		return $post_id;

	$post_type = get_post_type_object( $post->post_type );

	if ( !current_user_can( $post_type->cap->edit_post, $post_id ) )
		return $post_id;

	$post_meta = array();
	if (isset($_POST['timeline_category'])) {
		$post_meta['timeline_category'] = $_POST['timeline_category'];
		if ($post_meta['timeline_category'] == 0) {
			$post_meta['timeline_category'] = '';
		}
	}
	if (isset($_POST['timeline_order'])) $post_meta['timeline_order'] = $_POST['timeline_order'];
	if (isset($_POST['timeline_date'])) $post_meta['timeline_date'] = $_POST['timeline_date'];
	if (isset($_POST['timeline_date_item'])) $post_meta['timeline_date_item'] = $_POST['timeline_date_item'];

	foreach ($post_meta as $key => $value) {
		$new_meta_value = ( isset( $value ) ? $value : '' );
		$meta_key = $key;
		$meta_value = get_post_meta( $post_id, $meta_key, true );
		if ( $new_meta_value && '' == $meta_value )
			add_post_meta( $post_id, $meta_key, $new_meta_value, true );
		elseif ( $new_meta_value && $new_meta_value != $meta_value )
			update_post_meta( $post_id, $meta_key, $new_meta_value );
		elseif ( '' == $new_meta_value && $meta_value )
			delete_post_meta( $post_id, $meta_key, $meta_value );
	}

}
//Timeline category selector for timeline template

?>